from Paperl.Paperc import prDebug, prDebugging, prError, prWarring, prSuccess, checkSystem, checkPython
from Paperl.Paperui import *
from Paperl.Papers import *
from Paperl.Papert import *
from Padevel import *


__version__ = "0.0.3"


checkSystem()
checkPython()